@@ -1410,7 +1410,6 @@ int mailmime_language_parse(const char * message, size_t length,
   int r;
   int res;
   clist * list;
-  int first;
   struct mailmime_language * language;
 
   cur_token = * indx;
@@ -1421,8 +1420,6 @@ int mailmime_language_parse(const char * message, size_t length,
     goto err;
   }
 
-  first = TRUE;
-
   while (1) {
     char * atom;
 
