@@ -369,180 +369,6 @@ int mailmime_encoded_word_parse(const char * message, size_t length,
                                 struct mailmime_encoded_word ** result,
                                 int * p_has_fwd, int * p_missing_closing_quote)
 {
-#if 0
-  size_t cur_token;
-  char * charset;
-  int encoding;
-  char * text;
-  size_t end_encoding;
-  char * decoded;
-  size_t decoded_len;
-  struct mailmime_encoded_word * ew;
-  int r;
-  int res;
-  int opening_quote;
-  int end;
-  int has_fwd;
-  int missing_closing_quote;
-  
-  cur_token = * indx;
-
-  missing_closing_quote = 0;
-  has_fwd = 0;
-  r = mailimf_fws_parse(message, length, &cur_token);
-  if (r == MAILIMF_NO_ERROR) {
-    has_fwd = 1;
-  }
-  if ((r != MAILIMF_NO_ERROR) && (r != MAILIMF_ERROR_PARSE)) {
-    res = r;
-    goto err;
-  }
-
-  opening_quote = FALSE;
-  r = mailimf_char_parse(message, length, &cur_token, '\"');
-  if (r == MAILIMF_NO_ERROR) {
-    opening_quote = TRUE;
-  }
-  else if (r == MAILIMF_ERROR_PARSE) {
-    /* do nothing */  
-  }
-  else {
-    res = r;
-    goto err;
-  }
-
-  r = mailimf_token_case_insensitive_parse(message, length, &cur_token, "=?");
-  if (r != MAILIMF_NO_ERROR) {
-    res = r;
-    goto err;
-  }
-
-  r = mailmime_charset_parse(message, length, &cur_token, &charset);
-  if (r != MAILIMF_NO_ERROR) {
-    res = r;
-    goto err;
-  }
-
-  r = mailimf_char_parse(message, length, &cur_token, '?');
-  if (r != MAILIMF_NO_ERROR) {
-    res = r;
-    goto free_charset;
-  }
-
-  r = mailmime_encoding_parse(message, length, &cur_token, &encoding);
-  if (r != MAILIMF_NO_ERROR) {
-    res = r;
-    goto free_charset;
-  }
-
-  r = mailimf_char_parse(message, length, &cur_token, '?');
-  if (r != MAILIMF_NO_ERROR) {
-    res = r;
-    goto free_charset;
-  }
-
-  end = FALSE;
-  end_encoding = cur_token;
-  while (1) {
-    if (end_encoding >= length)
-      break;
-
-    if (end_encoding + 1 < length) {
-      if ((message[end_encoding] == '?') && (message[end_encoding + 1] == '=')) {
-        end = TRUE;
-      }
-    }
-
-    if (end)
-      break;
-
-    end_encoding ++;
-  }
-
-  decoded_len = 0;
-  decoded = NULL;
-  switch (encoding) {
-  case MAILMIME_ENCODING_B:
-    r = mailmime_base64_body_parse(message, end_encoding,
-				   &cur_token, &decoded,
-				   &decoded_len);
-      
-    if (r != MAILIMF_NO_ERROR) {
-      res = r;
-      goto free_charset;
-    }
-    break;
-  case MAILMIME_ENCODING_Q:
-    r = mailmime_quoted_printable_body_parse(message, end_encoding,
-					     &cur_token, &decoded,
-					     &decoded_len, TRUE);
-
-    if (r != MAILIMF_NO_ERROR) {
-      res = r;
-      goto free_charset;
-    }
-
-    break;
-  }
-
-  text = malloc(decoded_len + 1);
-  if (text == NULL) {
-    res = MAILIMF_ERROR_MEMORY;
-    goto free_charset;
-  }
-
-  if (decoded_len > 0)
-    memcpy(text, decoded, decoded_len);
-  text[decoded_len] = '\0';
-
-  mailmime_decoded_part_free(decoded);
-
-  r = mailimf_token_case_insensitive_parse(message, length, &cur_token, "?=");
-#if 0
-  if (r != MAILIMF_NO_ERROR) {
-    res = r;
-    goto free_encoded_text;
-  }
-#endif
-
-  if (opening_quote) {
-    r = mailimf_char_parse(message, length, &cur_token, '\"');
-#if 0
-    if ((r != MAILIMF_NO_ERROR) && (r != MAILIMF_ERROR_PARSE)) {
-      res = r;
-      goto free_encoded_text;
-    }
-#endif
-    if (r == MAILIMF_ERROR_PARSE) {
-      missing_closing_quote = 1;
-    }
-  }
-  
-  /* fix charset */
-  if (strcasecmp(charset, "utf8") == 0) {
-    free(charset);
-    charset = strdup("utf-8");
-  }
-  ew = mailmime_encoded_word_new(charset, text);
-  if (ew == NULL) {
-    res = MAILIMF_ERROR_MEMORY;
-    goto free_encoded_text;
-  }
-
-  * result = ew;
-  * indx = cur_token;
-  * p_has_fwd = has_fwd;
-  * p_missing_closing_quote = missing_closing_quote;
-  
-  return MAILIMF_NO_ERROR;
-
- free_encoded_text:
-  mailmime_encoded_text_free(text);
- free_charset:
-  mailmime_charset_free(charset);
- err:
-  return res;
-#else
   /*
   Parse the following, when a unicode character encoding is split.
   =?UTF-8?B?4Lij4Liw4LmA4Lia4Li04LiU4LiE4Lin4Liy4Lih4Lih4Lix4LiZ4Liq4LmM?=
@@ -821,13 +647,11 @@ free_decoded:
   mailmime_decoded_part_free(decoded);
 free_body:
   free(body);
-free_encoded_text:
   mailmime_encoded_text_free(text);
 free_charset:
   mailmime_charset_free(charset);
 err:
   return res;
-#endif
 }
 
 static int mailmime_charset_parse(const char * message, size_t length,
